CpuPower enum

CPU power mode hint passed through to Paddle Lite on Android/iOS. Mirrors paddle::lite_api::PowerMode (see ppredictor.cpp). Ignored on web.

Inheritance
Available extensions

Values

high → const CpuPower
const CpuPower('LITE_POWER_HIGH')
low → const CpuPower
const CpuPower('LITE_POWER_LOW')
full → const CpuPower
const CpuPower('LITE_POWER_FULL')
noBind → const CpuPower
const CpuPower('LITE_POWER_NO_BIND')
randHigh → const CpuPower
const CpuPower('LITE_POWER_RAND_HIGH')
randLow → const CpuPower
const CpuPower('LITE_POWER_RAND_LOW')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CpuPower>
A constant List of the values in this enum, in order of their declaration.