MethodChannelFlutterPaddleOcr class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required ModelSource source, int cpuThreadNum = 4, CpuPower cpuPower = CpuPower.high, bool useOpenCL = false}) Future<Object>
Loads models and returns an opaque engine handle.
override
dispose(Object handle) Future<void>
Releases the native engine associated with handle.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognize(Object handle, Uint8List imageBytes, {int maxSideLen = 960, bool runDetection = true, bool runClassification = false, bool runRecognition = true}) Future<List<OcrResult>>
Runs OCR on an image encoded in a browser/native-decodable format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited